netapp_ontap.models.shelf_remote API documentation
Description: Copyright &copy; 2020 NetApp Inc. All rights reserved.

# Module `netapp_ontap.models.shelf_remote`

Copyright © 2020 NetApp Inc. All rights reserved.

## Classes

`class ShelfRemoteSchema (*, only: typing.Union = None, exclude: typing.Union = (), many: bool = False, context: typing.Dict = None, load_only: typing.Union = (), dump_only: typing.Union = (), partial: typing.Union = False, unknown: str = None)`

  The fields of the ShelfRemote object

  ### Ancestors

  - netapp_ontap.resource.ResourceSchema
  - marshmallow.schema.Schema
  - marshmallow.base.SchemaABC

  ### Class variables

  `chassis GET POST PATCH`

    The chassis field of the shelf_remote.

  `device GET POST PATCH`

    The device field of the shelf_remote.

  `mac_address GET POST PATCH`

    The mac_address field of the shelf_remote.

  `phy GET POST PATCH`

    The phy field of the shelf_remote.

    Example: 12

  `port GET POST PATCH`

    The port field of the shelf_remote.

  `wwn GET POST PATCH`

    The wwn field of the shelf_remote.

    Example: 50000D1703544B80